@@ -30,27 +30,16 @@
 The only class exposed by this package is :class:`nocasedict.NocaseDict`.
 """
 
-from __future__ import print_function, absolute_import
 
-import sys
 import os
-import warnings
-from collections import OrderedDict
 from collections.abc import MutableMapping, KeysView, ValuesView, ItemsView
 from typing import Any, AnyStr, NoReturn, Optional, Iterator, Tuple, Dict
 
-from ._utils import _stacklevel_above_nocasedict
-
 __all__ = ['NocaseDict']
 
-# Starting with Python 3.7, the standard dict is guaranteed to be ordered.
-# Note: In CPython, that already happened in 3.6, but it was not guaranteed
-# for all implementations.
-# pylint: disable=invalid-name
-if sys.version_info[0:2] >= (3, 7):
-    _ODICT_TYPE = dict
-else:
-    _ODICT_TYPE = OrderedDict
+# Note: The minimum version of Python supported for nocasedict guarantees that
+# the standard dict is ordered, so nocasedict code uses the standard dict when
+# an ordered dict is needed.
 
 Key = Optional[AnyStr]
 
@@ -77,18 +66,18 @@ class _DictView:
         return len(self._dict)
 
     def __contains__(self, x):
+        # pylint: disable=invalid-name
         return x in iter(self)
 
     def __reversed__(self):
         return reversed(list(iter(self)))
 
     def __repr__(self):
-        return "{t}({d!r})".format(
-            t=self.__class__.__name__, d=self._dict)
+        return f"{self.__class__.__name__}({self._dict!r})"
 
 
 class dict_keys(_DictView, KeysView):
-    # pylint: disable=too-few-public-methods
+    # pylint: disable=too-few-public-methods,invalid-name
     """
     Dictionary values view.
     """
@@ -101,7 +90,7 @@ class dict_keys(_DictView, KeysView):
 
 
 class dict_values(_DictView, ValuesView):
-    # pylint: disable=too-few-public-methods
+    # pylint: disable=too-few-public-methods,invalid-name
     """
     Dictionary values view.
     """
@@ -114,7 +103,7 @@ class dict_values(_DictView, ValuesView):
 
 
 class dict_items(_DictView, ItemsView):
-    # pylint: disable=too-few-public-methods
+    # pylint: disable=too-few-public-methods,invalid-name
     """
     Dictionary items view.
     """
@@ -264,7 +253,7 @@ class NocaseDict(MutableMapping):
 
         # The internal dictionary, with casefolded keys. An item in this dict
         # is the tuple (original key, value).
-        self._data: Dict[Key, Any] = _ODICT_TYPE()
+        self._data: Dict[Key, Any] = {}
 
         self.update(*args, **kwargs)
 
@@ -326,7 +315,7 @@ class NocaseDict(MutableMapping):
         try:
             return self._data[k][1]
         except KeyError:
-            key_error = KeyError("Key {0!r} not found".format(key))
+            key_error = KeyError(f"Key {key!r} not found")
             key_error.__cause__ = None  # Suppress 'During handling..'
             raise key_error  # pylint: disable=raise-missing-from
 
@@ -358,7 +347,7 @@ class NocaseDict(MutableMapping):
         try:
             del self._data[k]
         except KeyError:
-            key_error = KeyError("Key {0!r} not found".format(key))
+            key_error = KeyError(f"Key {key!r} not found")
             key_error.__cause__ = None  # Suppress 'During handling..'
             raise key_error  # pylint: disable=raise-missing-from
 
@@ -537,10 +526,9 @@ class NocaseDict(MutableMapping):
 
         Invoked when using e.g.: ``repr(ncd)``
         """
-        items = ["{0!r}: {1!r}".format(key, value)
-                 for key, value in self.items()]
+        items = [f"{key!r}: {value!r}" for key, value in self.items()]
         items_str = ', '.join(items)
-        return "{0.__class__.__name__}({{{1}}})".format(self, items_str)
+        return f"{self.__class__.__name__}({{{items_str}}})"
 
     def update(self, *args, **kwargs) -> None:
         # pylint: disable=arguments-differ,signature-differs
@@ -599,23 +587,12 @@ class NocaseDict(MutableMapping):
         if args:
             if len(args) > 1:
                 raise TypeError(
-                    "Expected at most 1 positional argument, got {n}".
-                    format(n=len(args)))
+                    f"Expected at most 1 positional argument, got {len(args)}")
             other = args[0]
             try:
                 # Try mapping / dictionary
                 for key in other.keys():
                     self[key] = other[key]
-                # pylint: disable=unidiomatic-typecheck
-                if type(other) is dict and _ODICT_TYPE is not dict and \
-                        len(other.keys()) > 1:
-                    warnings.warn(
-                        "Before Python 3.7, initializing or updating a "
-                        "NocaseDict object from a dict object with more than "
-                        "one item is not guaranteed to preserve the order of "
-                        "its items",
-                        UserWarning,
-                        stacklevel=_stacklevel_above_nocasedict())
             except AttributeError:
                 # Expecting an iterable
 
@@ -634,9 +611,8 @@ class NocaseDict(MutableMapping):
                             key, value = item
                         except ValueError as exc:
                             value_error = ValueError(
-                                "Cannot unpack positional argument item #{i} "
-                                "of type {t} into key, value: {exc}".
-                                format(i=i, t=type(item), exc=exc))
+                                f"Cannot unpack positional argument item #{i} "
+                                f"of type {type(item)} into key, value: {exc}")
                             value_error.__cause__ = None  # Suppress 'During..'
                             # pylint: disable=raise-missing-from
                             raise value_error
@@ -644,13 +620,6 @@ class NocaseDict(MutableMapping):
 
         for key, val in kwargs.items():
             self[key] = val
-        if len(kwargs) > 1 and _ODICT_TYPE is not dict:
-            warnings.warn(
-                "Before Python 3.7, initializing or updating a NocaseDict "
-                "object from more than one keyword argument is not guaranteed "
-                "to preserve their order",
-                UserWarning,
-                stacklevel=_stacklevel_above_nocasedict())
 
     def clear(self) -> None:
         """
@@ -725,8 +694,8 @@ class NocaseDict(MutableMapping):
         is not supported.
         """
         raise TypeError(
-            "'{}' not supported between instances of '{}' and '{}'".
-            format(op, type(self), type(other)))
+            f"'{op}' not supported between instances of '{type(self)}' and "
+            f"'{type(other)}'")
 
     def __lt__(self, other: Any) -> NoReturn:
         self._raise_ordering_not_supported(other, '<')
@@ -739,3 +708,52 @@ class NocaseDict(MutableMapping):
 
     def __le__(self, other: Any) -> NoReturn:
         self._raise_ordering_not_supported(other, '<=')
+
+    def __or__(self, other: Any) -> 'NocaseDict':
+        """
+        Return the union of this dictionary and the other dictionary.
+
+        This operation is not commutative: If a key from the other dictionary
+        is already present in this dictionary (looked up case-insensitively),
+        its key and value is updated (without affecting its position in the
+        dictionary iteration order). Otherwise, an item with the key and value
+        is added to this dictionary.
+
+        The other dictionary may be a :class:`NocaseDict` object or any other
+        mapping. In all cases, the matching of keys takes place
+        case-insensitively.
+
+        Invoked when using e.g.: ``ncd | other``
+
+        Raises:
+          AttributeError: The key does not have the casefold method.
+        """
+        result = NocaseDict(self)
+        result.update(other)
+        return result
+
+    def __ror__(self, other: Any) -> 'NocaseDict':
+        result = NocaseDict(other)
+        result.update(self)
+        return result
+
+    def __ior__(self, other: Any) -> 'NocaseDict':
+        """
+        Update the dictionary from the other dictionary.
+
+        If a key is already present in the dictionary (looked up
+        case-insensitively), its key and value is updated (without affecting
+        its position in the dictionary iteration order). Otherwise, an item
+        with the key and value is added to the dictionary.
+
+        The other dictionary may be a :class:`NocaseDict` object or any other
+        mapping. In all cases, the matching of keys takes place
+        case-insensitively.
+
+        Invoked when using e.g.: ``ncd |= other``
+
+        Raises:
+          AttributeError: The key does not have the casefold method.
+        """
+        self.update(other)
+        return self
